@@ -885,7 +885,8 @@ gchar *g_utf8_collate_key_for_filename (const gchar *str,
                                         gssize       len) G_GNUC_MALLOC;
 
 GLIB_AVAILABLE_IN_2_52
-gchar *g_utf8_make_valid (const gchar *str);
+gchar *g_utf8_make_valid (const gchar *str,
+                          gssize       len) G_GNUC_MALLOC;
 
 G_END_DECLS
 
